@@ -142,7 +142,7 @@ def pre_process_yield(yield_df):
     # Remove all 'geometry' NoneType values :
     yield_df = yield_df[~yield_df["geometry"].isna()]
     yield_df["centroid"] = yield_df["geometry"].map(lambda p: p.centroid)
-    yield_df["geometry"] = yield_df["geometry"].simplify(10)
+    # yield_df["geometry"] = yield_df["geometry"].simplify(1000000)
     # print(type(yield_df['geometry'][0].centroid))
 
     # Remove 'county_code' after merging :
